@@ -57,6 +57,7 @@ class Metric:
         no_lint: Optional[List[str]] = None,
         data_sensitivity: Optional[List[str]] = None,
         defined_in: Optional[Dict] = None,
+        telemetry_mirror: Optional[str] = None,
         _config: Dict[str, Any] = None,
         _validated: bool = False,
     ):
@@ -90,6 +91,8 @@ class Metric:
                 getattr(DataSensitivity, x) for x in data_sensitivity
             ]
         self.defined_in = defined_in
+        if telemetry_mirror is not None:
+            self.telemetry_mirror = telemetry_mirror
 
         # _validated indicates whether this metric has already been jsonschema
         # validated (but not any of the Python-level validation).
@@ -322,8 +325,10 @@ class Jwe(Metric):
     typename = "jwe"
 
     def __init__(self, *args, **kwargs):
-        self.decrypted_name = kwargs.pop("decrypted_name")
-        super().__init__(*args, **kwargs)
+        raise ValueError(
+            "JWE support was removed. "
+            "If you require this send an email to glean-team@mozilla.com."
+        )
 
 
 class Labeled(Metric):
@@ -361,4 +366,12 @@ class LabeledCounter(Labeled, Counter):
     typename = "labeled_counter"
 
 
+class Rate(Metric):
+    typename = "rate"
+
+    def __init__(self, *args, **kwargs):
+        self.denominator_metric = kwargs.pop("denominator_metric", None)
+        super().__init__(*args, **kwargs)
+
+
 ObjectTree = Dict[str, Dict[str, Union[Metric, pings.Ping]]]
