@@ -47,7 +47,7 @@ def test_extra_info_generator():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -60,7 +60,7 @@ def test_extra_info_generator():
         type="labeled_counter",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
@@ -74,7 +74,7 @@ def test_extra_info_generator():
         type="timespan",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         time_unit="day",
         notification_emails=["nobody@example.com"],
         description="description...",
@@ -139,6 +139,24 @@ def test_metrics_docs():
     )
 
 
+def test_review_title():
+    index = 1
+
+    assert (
+        markdown.ping_review_title(
+            "https://bugzilla.mozilla.org/show_bug.cgi?id=1581647", index
+        )
+        == "Bug 1581647"
+    )
+    assert (
+        markdown.ping_review_title(
+            "https://github.com/mozilla-mobile/fenix/pull/1707", index
+        )
+        == "mozilla-mobile/fenix#1707"
+    )
+    assert markdown.ping_review_title("http://example.com/reviews", index) == "Review 1"
+
+
 def test_reasons(tmpdir):
     tmpdir = Path(str(tmpdir))
 
@@ -213,7 +231,7 @@ def test_data_sensitivity():
         type="event",
         category="category",
         name="metric",
-        bugs=[42],
+        bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
